Package: calibrator
Type: Package
Title: Bayesian Calibration of Complex Computer Codes
Version: 1.2-8
Authors@R: person(given=c("Robin", "K. S."), family="Hankin", role = c("aut","cre"), email="hankin.robin@gmail.com", comment = c(ORCID = "0000-0001-5982-0415"))
Depends: R (>= 2.0.0), emulator (>= 1.2-11), mvtnorm
Imports: cubature
Maintainer: Robin K. S. Hankin <hankin.robin@gmail.com>
Description: Performs Bayesian calibration of computer models as per
 Kennedy and O'Hagan 2001.  The package includes routines to find the
 hyperparameters and parameters; see the help page for stage1() for a
 worked example using the toy dataset.  A tutorial is provided in the
 calex.Rnw vignette; and a suite of especially simple one dimensional
 examples appears in inst/doc/one.dim/.
License: GPL-2
URL: https://github.com/RobinHankin/calibrator.git
BugReports: https://github.com/RobinHankin/calibrator/issues
NeedsCompilation: no
Packaged: 2019-03-06 20:06:53 UTC; rhankin
Author: Robin K. S. Hankin [aut, cre] (<https://orcid.org/0000-0001-5982-0415>)
Repository: CRAN
Date/Publication: 2019-03-07 06:52:58 UTC
Built: R 4.6.0; ; 2026-04-26 12:02:17 UTC; unix
