This directory holds some R files that show the calibrator software
working with a one-dimensional problem.  The independent variable x is
1-d, as is theta.

The master file is calex_1d.R; this calls the other R files in the
directory.
